#
# Copyright (C) 2007 Saket Sathe
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#
# $LastChangedBy: xaeroman $
# $LastChangedDate: 2007-07-24 19:49:16 +0530 (Tue, 24 Jul 2007) $
# $LastChangedRevision: 30 $
# 
#

from PackageExceptions import *

""" A module representing basic graph elements

    @namespace BaseElements

"""

class Vertex:
    """ Represents graph vertex

    """
    def __init__(self,vertexNumber):
        """ Constructs graph vertex given a vertex number

            @param vertexNumber Vertex number to be assigned to the created vertex
        """

        ## Vertex number
        self.vertexNumber = vertexNumber
        
    def getVertexNumber(self):
        """ Get vertex number

            @return vertexNumber Vertex number of this vertex
        """
        return self.vertexNumber
    
    def setVertexNumber(self,vertexNumber):
        """ Set vertex number

            @param vertexNumber New vertex number
        """
        self.vertexNumber = vertexNumber

class WeightedVertex(Vertex):
    """ Represents a weighted vertex
    """
    def __init__(self,vertexNumber,vertexWeight):
        """ Constructs a weighted vertex given a vertex number and vertex weight

            @param vertexNumber vertex number to be assigned to the created vertex
            @param vertexWeight vertex weight to be assigned to the created vertex
        """
        Vertex.__init__(self,vertexNumber)

        ## Vertex weight 
        self.vertexWeight = vertexWeight

    def getWeight(self):
        """ Get vertex weight

            @return vertexWeight Vertex weight of this vertex
        """
        return self.vertexWeight
    
    def setWeight(self,vertexWeight):
        """ Set vertex weight

            @param vertexWeight New vertex weight
        """
        self.vertexWeight = vertexWeight

class WeightedVertices:
    """  Represents a collection of weighted vertices of type BaseElements::WeightedVertices
    
    """
    
    def __init__(self):
        """ Initialize an empty collection

        """
        ## A dictonary of weighted vertices indexed by vertex numbers and values of type BaseElements::WeightedVertex
        self.weightedVertices = {}
        
    def addVertex(self, weightedVertex):
        """ Add vertex to the collection

            @param weightedVertex Weighted vertex to be added. Should be of type BaseElements::WeightedVertex
        """
        self.weightedVertices[weightedVertex.vertexNumber] = weightedVerticex

    def delVertex(self, vertexNumber):
        """ Delete vertex from the collection

            @param vertexNumber Vertex number of the vertex to be deleted
        """
        del self.weightedVertices[vertexNumber]
        
    def getVertices(self):
        """ Get all vertices from the collection

            @return weightedVertices A dict of all weighted vertices indexed by vertex number
        """
        return self.weightedVertices
    
    def findVertex(self,vertexNumber):
        """ Find vertex in the collection

            @param vertexNumber Vertex number to be found
            @throws PackageExceptions::VertexError
            @return weightedVertex Found weighted vertex of type BaseElements::WeightedVertex
            
        """
        try:
            return self.weightedVertices[vertexNumber]
        except KeyError:
            raise VertexError(vertexNumber, ErrorMessages.vertexNotFound)


    def findWeight(self,vertexNumber):
        """ Find weight of a given vertex

           @param vertexNumber Vertex number of the vertex whose weight is to be found
           @return vertexWeight Weight of vertex
        """
        try:
            weightedVertex = self.findVertex(vertexNumber)
            return weightedVertex.vertexWeight
        except VertexError, e:
            print e.message

    
    def hasVertex(self, vertexNumber):
        """ Checks if vertex is present

            @param vertexNumber Vertex number to be checked
            @return 0 if vertex is found. Otherwise 1
        """
        try:
            rs = self.findVertex(vertexNumber)
            return 0
        except VertexError, e:
            return 1

class Edge:
    """ Represents graph edge

    """
    
    def __init__(self):
        """ Constructs an emtpy edge
        """
        ## Starting vertex of a edge of type BaseElements::Vertex
        self.startVertex = ''        

        ## Ending vertex of a edge of type BaseElements::Vertex
        self.endVertex = ''

    def __init__(self, startVertex, endVertex):
        """ Constructs a graph edge with given start and end vertices

            @param startVertex start vertex of the edge
            @param endVertex end vertex of the edge
        """
        self.startVertex = startVertex
        self.endVertex = endVertex
       
    def getStartVertex(self):
        """ Get the start vertex

            @return startVertex Start vertex of type BaseElements::Vertex
        """
        return self.startVertex
    
    def getEndVertex(self):
        """ Get the end vertex

            @return endVertex End vertex of type BaseElements::Vertex
        """
        return self.endVertex
    
    def setStartVertex(self, vertex):
        """ Set the start vertex

            @param startVertex Start vertex of type BaseElements::Vertex
        """
        self.startVertex = vertex
        
    def setEndVertex(self, vertex):
        """ Set the end vertex
                
            @param endVertex End vertex of type BaseElements::Vertex
        """
        self.endVertex = vertex


