#!/usr/bin/python
#
# Copyright (C) 2007 Saket Sathe
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#
# $LastChangedBy: xaeroman $
# $LastChangedDate: 2007-07-23 18:38:49 +0530 (Mon, 23 Jul 2007) $
# $LastChangedRevision: 25 $
# 
#

import getopt, sys
from RandomGraphs import *

def usage(paramDefaults):
    helpString = """
USAGE: ./genwebgraph.py [options]
        Command line tool for generating a synthetic web graph

DESCRIPTION

       -t, --threads=NUMBER
               Number of threads to use for the generation. Default: %s

       -o, --output=FILENAME
               File for storing output. Default: %s

       -f, --format=FMT
               Output format. Default: %s. Possible: 'simple' or 'dot'

       -v, --max-vertices=NUMBER
               Maximum number of vertices. Default: %s

       -e, --max-edges=NUMBER
               Maximum number of edges. Default: %s

       -h, --help
               Show this page
        """ % (paramDefaults['threads'], paramDefaults['output'], paramDefaults['format'], paramDefaults['max-vertices'], paramDefaults['max-edges'])

    print helpString
    return


if __name__=="__main__":
    paramDefaults = { 'threads' : '1' , 'output' : '/tmp/graph.pyg', 'format': 'simple', 'max-vertices':'100','max-edges':'100'}

    
    if len(sys.argv) == 1:
        usage(paramDefaults)
        sys.exit(0)
        
    try:
        opts, args = getopt.getopt(sys.argv[1:], "t:o:f:v:e:dh", ["threads=","output=","format=", "max-vertices=","max-edges=","help"])
    except getopt.GetoptError:
        usage(paramDefaults)
        sys.exit(2)
                      
    config = {}

    for param in paramDefaults:
        config[param] = paramDefaults[param]

    for o, a in opts:
        options = ("-t","--threads")
        if o in options:
           config[options[1][2:]] = a

        options = ("-o","--output")
        if o in options:
           config[options[1][2:]] = a

        options = ("-f","--format")
        if o in options:
           config[options[1][2:]] = a

        options = ("-v","--max-vertices")
        if o in options:
           config[options[1][2:]] = a

        options = ("-e","--max-edges")
        if o in options:
           config[options[1][2:]] = a
           
        options = ("-h","--help")
        if o in options:
            usage(paramDefaults)
            sys.exit(0)

    graph = PowerLawRandomGraph(int(config['max-vertices']),int(config['max-edges']))
    graph.generate(int(config['threads']))
    graph.writeEdges(str(config['output']),str(config['format']))
